@@ -75,8 +75,8 @@ parserInfo = OA.info (OA.helper <*> parseOptions) $
         [ "Terminal-based presentations using Pandoc"
         , ""
         , "Controls:"
-        , "- Next slide:             space, enter, l, right"
-        , "- Previous slide:         backspace, h, left"
+        , "- Next slide:             space, enter, l, right, pagedown"
+        , "- Previous slide:         backspace, h, left, pageup"
         , "- Go forward 10 slides:   j, down"
         , "- Go backward 10 slides:  k, up"
         , "- First slide:            0"
